@@ -1,5 +1,5 @@
 ;;; manifest.scm -- Guix manifest for continuous integration.
-;;; Copyright © 2023-2024 Ludovic Courtès <ludo@gnu.org>
+;;; Copyright © 2023-2025 Ludovic Courtès <ludo@gnu.org>
 ;;;
 ;;; This file is part of the GNU Shepherd.
 ;;;
@@ -24,7 +24,6 @@
               #:select (virtual-machine
                         virtualized-operating-system))
              ((gnu services) #:select (modify-services))
-             ((gnu services base) #:select (syslog-service-type))
              (gnu services)
              (gnu services shepherd)
              (gnu tests)
@@ -82,28 +81,6 @@ TARGET."
         config => (shepherd-configuration
                    (shepherd shepherd)))))))
 
-(define shepherd-system-log-service-type
-  (shepherd-service-type
-   'shepherd-system-log
-   (const (shepherd-service
-           (documentation "Shepherd's built-in system log (syslogd).")
-           (provision '(system-log syslogd))
-           (modules '((shepherd service system-log)))
-           (free-form #~(system-log-service))))
-   #t
-   (description
-    "Shepherd's built-in system log (syslogd).")))
-
-(define (operating-system-with-built-in-system-log os)
-  "Return @var{os} using the Shepherd's built-in @code{system-log} service
-instead of the Inetutils-based @code{syslog-service-type}."
-  (operating-system
-    (inherit os)
-    (services
-     (cons (service shepherd-system-log-service-type)
-           (modify-services (operating-system-user-services os)
-             (delete syslog-service-type))))))
-
 (define system-test/base
   ;; "Base" system test running against the latest Shepherd.
   (system-test
@@ -128,9 +105,11 @@ instead of the Inetutils-based @code{syslog-service-type}."
    (description "Test Guix System with the latest Shepherd and with the
 built-in system log (syslogd) service.")
    (value
+    ;; Note: As of Guix commit 8492a3c8962664db4bd0e7475f63be0ef59db87a (March
+    ;; 2025), '%base-services' includes a 'shepherd-system-log-service-type'
+    ;; instance.  Assume we're using a commit more recent than this.
     (let* ((os (marionette-operating-system
-                (operating-system-with-latest-shepherd
-                 (operating-system-with-built-in-system-log %simple-os))
+                (operating-system-with-latest-shepherd %simple-os)
                 #:imported-modules '((gnu services herd)
                                      (guix combinators))))
            (vm (virtual-machine os)))
