@@ -1,5 +1,5 @@
 ;; herd.scm -- The program to herd the Shepherd.
-;; Copyright (C) 2013-2014, 2016, 2018-2019, 2021-2024 Ludovic Courtès <ludo@gnu.org>
+;; Copyright (C) 2013-2014, 2016, 2018-2019, 2021-2025 Ludovic Courtès <ludo@gnu.org>
 ;; Copyright (C) 2002, 2003 Wolfgang Jährling <wolfgang@pro-linux.de>
 ;;
 ;; This file is part of the GNU Shepherd.
@@ -422,7 +422,7 @@ calendar event."
                                                 ('name names)
                                                 ('address addresses)
                                                 _ ...) ...))
-                        _ ...)
+                        rest ...)
         ;; TRANSLATORS: "Inetd" refers to a type of service and should be kept
         ;; as-is.
         (format #t (l10n "  Inetd-style service listening on ~a endpoint:~%"
@@ -432,13 +432,19 @@ calendar event."
         (for-each (lambda (address)
                     (format #t "    - ~a~%"
                             (socket-address->string address)))
-                  addresses))
+                  addresses)
+        ;; The 'command' key appeared in version 1.0.4.
+        (match (assoc 'command rest)
+          (#f #t)
+          (('command command)
+           (format #t (l10n "  Command: ~a~%")
+                   (shell-quoted-command command)))))
        (('systemd-service ('version 0)
                           ('endpoints (('endpoint ('version 0)
                                                   ('name names)
                                                   ('address addresses)
                                                   _ ...) ...))
-                          _ ...)
+                          rest ...)
         ;; TRANSLATORS: "Systemd" should be kept untranslated.
         (format #t (l10n "  Systemd-style service listening on ~a endpoint:~%"
                          "  Systemd-style service listening on ~a endpoints:~%"
@@ -447,7 +453,13 @@ calendar event."
         (for-each (lambda (name address)
                     (format #t "    - ~a (~s)~%"
                             (socket-address->string address) name))
-                  names addresses))
+                  names addresses)
+        ;; The 'command' key appeared in version 1.0.4.
+        (match (assoc 'command rest)
+          (#f #t)
+          (('command command)
+           (format #t (l10n "  Command: ~a~%")
+                   (shell-quoted-command command)))))
        (('timer ('version 0)
                 ('event event) ('action action)
                 ('processes processes) _ ...)
@@ -531,8 +543,8 @@ to upgrade).~%"))))
     ((time _ ...)
      (format #t (highlight/warn (l10n "  Last respawned on ~a.~%"))
              (time->string time))
-     (match (at-most log-history-size
-                     (live-service-process-exit-statuses service))
+     (match (reverse (at-most log-history-size
+                              (live-service-process-exit-statuses service)))
        (((statuses . times) ...)
         ;; Since SERVICE was respawned, show a log of exit times and statuses.
         (format #t (l10n "  Latest exit:~%"
