@@ -1,5 +1,5 @@
 ;; system-log.scm -- Reading from the "system log" or "syslog".
-;; Copyright (C) 2024 Ludovic Courtès <ludo@gnu.org>
+;; Copyright (C) 2024-2025 Ludovic Courtès <ludo@gnu.org>
 ;;
 ;; This file is part of the GNU Shepherd.
 ;;
@@ -55,6 +55,7 @@
 
             kernel-log-file
             default-max-silent-time
+            default-message-destination-procedure
             system-log-service))
 
 ;; Message sent to the system log (minus its timestamp).
@@ -121,10 +122,12 @@
           %system-log-priority-mask))
 
 (define %system-log-message-rx
-  ;; Regexp matching system log messages.  Example:
+  ;; Regexp matching the prefix of system log messages.  Example:
   ;;   <29>Jun 22 16:41:30 wpa_supplicant[303]: whatever
-  (make-regexp "<([0-9]+)> ?([[:alpha:]]{3} +[0-9]+ [0-9]+:[0-9]+:[0-9]+ )?\
-(.*)"))
+  ;; Note: Do not match the actual message (the suffix) because it might
+  ;; contain Unicode code points and 'regexp-exec' might be buggy in that
+  ;; case: <https://bugs.gnu.org/77392>.
+  (make-regexp "<([0-9]+)> ?([[:alpha:]]{3} +[0-9]+ [0-9]+:[0-9]+:[0-9]+ )?"))
 
 (define %default-priority (system-log-priority notice))
 (define %default-facility (system-log-facility user))
@@ -139,7 +142,7 @@ representing it."
     (m
      (let* ((facility+priority (string->number (match:substring m 1))))
        (system-log-message facility+priority
-                           (match:substring m 3) sender)))))
+                           (match:suffix m) sender)))))
 
 (define* (read-system-log-message port #:optional sender)
   "Read a system log message from @var{port}.  Return the end-of-file object
@@ -334,8 +337,12 @@ system log file '~a'.")
                   (loop (vhash-cons file port (vhash-delete file ports))
                         messages)
                   (loop ports messages))))))
+        (('set-process-id pid)                    ;ignore
+         (loop ports messages))
         ('terminate
-         (local-output (l10n "Closing ~a system log ports.")
+         (local-output (l10n "Closing ~a system log port."
+                             "Closing ~a system log ports."
+                             (vlist-length ports))
                        (vlist-length ports))
          (vhash-fold (lambda (file port _)
                        (close-port port)
