@@ -1,5 +1,5 @@
 # GNU Shepherd --- Make sure shepherd tolerates misbehaved clients.
-# Copyright © 2016, 2018, 2022 Ludovic Courtès <ludo@gnu.org>
+# Copyright © 2016, 2018, 2022, 2025 Ludovic Courtès <ludo@gnu.org>
 #
 # This file is part of the GNU Shepherd.
 #
@@ -23,10 +23,11 @@ socket="t-socket-$$"
 conf="t-conf-$$"
 log="t-log-$$"
 pid="t-pid-$$"
+client="t-client-$$"
 
 herd="herd -s $socket"
 
-trap "cat $log || true; rm -f $socket $conf $stamp $log;
+trap "cat $log || true; rm -f $socket $conf $stamp $log $client;
       test -f $pid && kill \`cat $pid\` || true; rm -f $pid" EXIT
 
 rm -f "$pid"
@@ -93,4 +94,18 @@ $herd status
 
 $herd status
 
+cat > "$client" <<EOF
+;; -*- coding: utf-8 -*-
+(use-modules (shepherd comm))
+
+(let ((sock (open-connection "$socket")))
+  (set-port-encoding! sock "ISO-8859-1")
+  (set-port-conversion-strategy! sock 'error)
+  (display "(Café, ça te dit ?)\n" sock)
+  (close-port sock))
+EOF
+
+guile --no-auto-compile "$client"
+$herd status
+
 cat "$log"
