@@ -1,5 +1,5 @@
 # GNU Shepherd --- Test transient services.
-# Copyright © 2022-2024 Ludovic Courtès <ludo@gnu.org>
+# Copyright © 2022-2025 Ludovic Courtès <ludo@gnu.org>
 #
 # This file is part of the GNU Shepherd.
 #
@@ -44,12 +44,17 @@ cat > "$conf" <<EOF
       '(begin
          (use-modules (ice-9 match) (ice-9 rdelim))
 
+         (setvbuf (current-output-port) 'line)
+         (setvbuf (current-error-port) 'line)
+
          (display "starting\n")
          (unless (= (string->number (getenv "LISTEN_PID")) (getpid))
            (error "wrong pid!" (getenv "LISTEN_PID")))
          (unless (= (string->number (getenv "LISTEN_FDS")) 1)
            (error "wrong LISTEN_FDS!" (getenv "LISTEN_FDS")))
          (let ((sock (fdopen 3 "r+0")))
+           (unless (zero? (logand O_NONBLOCK (fcntl sock F_GETFL)))
+             (error "socket is non-blocking!" sock))
            (match (accept sock)
              ((connection . peer)
               (format #t "accepting connection from ~s~%" peer)
@@ -111,6 +116,7 @@ test $($herd status | grep '\+' | wc -l) -eq 2
 
 $herd status test-systemd-unix | grep "Systemd-style"
 $herd status test-systemd-unix | grep "$service_socket"
+$herd status test-systemd-unix | grep "Command: guile.*begin.*LISTEN_PID"
 
 test "$(file_permissions "$service_socket_dir")" = "700"
 test "$(file_permissions "$service_socket")" = "666"
